# -*- coding: utf-8 -*-
from typing import Dict, Union

"""
Revar
~~~~~~~~~~~~~~~~~~~
Replace specific values ​​with custom variables.

:copyright: (c) 2021 decave27
:license: MIT, see LICENSE for more details.

"""
__all__ = ["replace", "Revar"]
__version__ = "0.2"
__author__ = "decave27"
__license__ = "MIT"
__copyright__ = "Copyright 2021 decave27"


def replace(
    source: Union[list, set, str, tuple], var: Dict[str, Union[str, int, bool, float]]
) -> None:
    """
    Replace specific values ​​with custom variables.

    Parameters
    ==========
    source: typing.Union[list, set, str, tuple]
        string or list before being replaced.
    var: typing.Dict[str, typing.Union[str, int, bool, float]]
        This is the variable setting for conversion.
    """
    if isinstance(source, (tuple, list, set)):
        for oldstr, newstr in var.items():
            if oldstr in source:
                source = [newstr if i == oldstr else i for i in source]
    if isinstance(source, str):
        for oldstr, newstr in var.items():
            source = source.replace(oldstr, newstr)
    return source


class Revar:
    def __init__(self, prefix: str) -> None:
        self.prefix = prefix

    """
    Replace specific values ​​with custom variables and prefix.

    Parameters
    ==========
    prefix : str
        Prefix to custom variable.

    """

    def replace(self, source: Union[list, set, str, tuple], **var) -> None:
        """
        Replace specific values ​​with custom variables and prefix.

        Parameters
        ==========
        source: typing.Union[list, set, str, tuple]
            string or list before being replaced.
        var: typing.Dict[str, typing.Union[str, int, bool, float]]
            This is the variable setting for conversion.
        ==========

        Example

        ```py
        revar.Revar.replace(source, var1="hello", var2="world")
        ```
        """
        if isinstance(source, (tuple, list, set)):
            for oldstr, newstr in var.items():
                if not oldstr in source:
                    source = [
                        newstr if i == (self.prefix + oldstr) else i for i in source
                    ]

        if isinstance(source, str):
            for variables in var.items():
                source = source.replace(self.prefix + variables[0], variables[1])
        return source



# -*- coding: utf-8 -*-

import os
import re

from setuptools import find_packages, setup

version = ""
with open("revar/__init__.py", encoding="UTF8") as f:
    version = re.search(
        r'^__version__\s*=\s*[\'"]([^\'"]*)[\'"]', f.read(), re.MULTILINE
    ).group(1)

path = os.path.dirname(os.path.realpath(__file__)).replace("\\", "/")

requirements = []
with open(f"{path}/requirements.txt", encoding="UTF8") as f:
    requirements = f.read().splitlines()

if not version:
    raise RuntimeError("version is not defined")

readme = ""
with open(f"{path}/README.md", encoding="UTF8") as f:
    readme = f.read()

setup(
    name="revar",
    author="decave27",
    author_email="decave27@gmail.com",
    url="https://github.com/decave27/revar",
    project_urls={
        "Source": "https://github.com/decave27/revar",
        "Tracker": "https://github.com/decave27/revar/issues",
    },
    version=version,
    keywords=["replace", "custom", "variable"],
    packages=find_packages(),
    license="MIT",
    description="Replace specific values ​​with custom variables",
    long_description=readme,
    long_description_content_type="text/markdown",
    include_package_data=True,
    install_requires=requirements,
    python_requires=">=3.7",
    classifiers=[
        "Environment :: Console",
        "Programming Language :: Python :: 3.7",
        "Programming Language :: Python :: 3.8",
        "Programming Language :: Python :: Implementation",
        "Programming Language :: Python :: Implementation :: CPython",
    ],
)
